@@ -15,10 +15,10 @@
 #' @param parallel if TRUE and a list is passed, computations are done in parallel. Some foreach back-end must be registered, like doParallel or doMC.
 #' @param ... additional arguments passed to other methods
 #' @return If cov.x and cov.y are passed, returns Krzanowski correlation
-#' 
+#'
 #' If cov.x is a list and cov.y is passed, same as above, but for all matrices in cov.x.
 #'
-#' If only a list is passed to cov.x, a matrix of Krzanowski correlation 
+#' If only a list is passed to cov.x, a matrix of Krzanowski correlation
 #' values.
 #' If repeat.vector is passed, comparison matrix is corrected above
 #' diagonal and repeatabilities returned in diagonal.
@@ -36,22 +36,20 @@
 #' KrzCor(c1, c2)
 #'
 #' KrzCor(list(c1, c2, c3))
-#'\dontrun{
+#'\donttest{
 #' reps <- unlist(lapply(list(c1, c2, c3), MonteCarloRep, 10, KrzCor, iterations = 10))
 #' KrzCor(list(c1, c2, c3), repeat.vector = reps)
 #'
 #' c4 <- RandomMatrix(10)
 #' KrzCor(list(c1, c2, c3), c4)
 #' }
+#'
+#' \dontrun{
 #' #Multiple threads can be used with some foreach backend library, like doMC or doParallel
-#' #library(doParallel)
-#' ##Windows:
-#' #cl <- makeCluster(2)
-#' #registerDoParallel(cl)
-#' ##Mac and Linux:
-#' #registerDoParallel(cores = 2)
-#' #KrzCor(list(c1, c2, c3), parallel = TRUE)
-#' 
+#' library(doMC)
+#' registerDoMC(cores = 2)
+#' KrzCor(list(c1, c2, c3), parallel = TRUE)
+#' }
 #' @keywords matrixcomparison
 #' @keywords matrixcorrelation
 #' @keywords Krzanowski
@@ -96,12 +94,12 @@ KrzCor.list <- function (cov.x, cov.y = NULL,
 #' @export
 KrzCor.mcmc_sample <- function (cov.x, cov.y, ret.dim = NULL, parallel = FALSE, ...)
 {
-  if (class (cov.y) == "mcmc_sample") {
+  if (is(cov.y, "mcmc_sample")) {
     n = dim(cov.x)[1]
     if(dim(cov.y)[1] != n) stop("samples must be of same size")
     cov.x <- alply(cov.x, 1)
-    output <- aaply(1:n, 1, function(i) KrzCor(cov.x, 
-                                               cov.y[i,,], 
+    output <- aaply(1:n, 1, function(i) KrzCor(cov.x,
+                                               cov.y[i,,],
                                                ret.dim = ret.dim)$krz,
                     .parallel = parallel)
     output <- as.numeric(output)
@@ -111,4 +109,4 @@ KrzCor.mcmc_sample <- function (cov.x, cov.y, ret.dim = NULL, parallel = FALSE,
                                   parallel = parallel)
   }
   return(output)
-}
\ No newline at end of file
+}
